<?php

namespace Dropwp_Chatfree;

/**
 * Base class for admin.
 *
 */
class Dropwp_Admin {

    public $importer_name = 'Dropwp Importer';
    public $importer_id = 'dropwp';

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * [$plugin_dir_url description]
	 * @var [type]
	 */
	protected $plugin_dir_url;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->plugin_dir_url = plugin_dir_url( trim( preg_replace( '@\(.*\(.*$@', '', __FILE__, 1 ) ) );
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'select2', str_replace( array( 'http:', 'https:' ), '', WC()->plugin_url() ) . '/assets/' . 'css/select2.css' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_register_script( 'select2', WC()->plugin_url() . '/assets/js/select2/select2.min.js', array( 'jquery' ), '3.5.4' );
	}

    /**
	 * Register the stylesheets for the admin area. Only for settings page.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_custom_styles() {

	}

	/**
	 * Register the JavaScript for the admin area. Only for settings page.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_custom_scripts() {
		wp_enqueue_script('jquery');
		wp_enqueue_script('select2');
	}

	/**
	*
	*/
	public function settings_header ( $param ) {

	}

    /**
     * Add a configuration field
     */
    public function add_config( $params ) {
        $name = isset( $params['name'] ) ? $params['name'] : '';
        $title = isset( $params['title'] ) ? $params['title'] : '';
        $page = isset( $params['page'] ) ? $params['page'] : '';
        $section = isset( $params['section'] ) ? $params['section'] : '';
        $default = isset( $params['default'] ) ? $params['default'] : '';
		$values = isset( $params['values'] ) ? $params['values'] : array();
		$help = isset( $params['help'] ) ? $params['help'] : '';
		$description = isset( $params['description'] ) ? $params['description'] : '';
        $validation = isset( $params['validation'] ) ? $params['validation'] : 'options_validate';
        $type = $params['type'];
        $field_callback = 'field_text';
        switch ( strtolower( $params['type'] ) ) {
            case 'checkbox':
                $field_callback = 'field_checkbox';
                $callback_options = array(
                    'name' => $name,
                    'title' => $title,
                    'default' => $default,
					'help' => $help,
                );
                break;

			case 'select':
                $field_callback = 'field_select';
                $callback_options = array(
                    'name' => $name,
                    'title' => $title,
                    'default' => $default,
					'values' => $values,
					'help' => $help,
                );
                break;

			case 'multiselect':
                $field_callback = 'field_multi_select';
                $callback_options = array(
                    'name' => $name,
                    'title' => $title,
                    'default' => $default,
					'values' => $values,
					'help' => $help,
                );
                break;

			case 'radio':
                $field_callback = 'field_radio';
                $callback_options = array(
                    'name' => $name,
                    'title' => $title,
                    'default' => $default,
					'values' => $values,
					'help' => $help,
                );
                break;

			case 'info':
				$field_callback = 'field_info';
				$callback_options = array(
					'title' => $title,
					'description' => $description,
					'help' => $help,
				);
				break;

			case 'simple_textarea':
                $field_callback = 'field_simpletextarea';
                $callback_options = array(
                    'name' => $name,
                    'help' => $help,
                );
                break;

            case 'textarea':
                $field_callback = 'field_textarea';
                $callback_options = array(
                    'name' => $name,
                    'help' => $help,
                );
                break;

            case 'hidden':
                $field_callback = 'field_hidden';
                $callback_options = array(
                    'name' => $name,
                );
                break;

            default:
                $field_callback = 'field_text';
                $callback_options = array(
                    'name' => $name,
					'help' => $help,
                );
                break;
        }
        add_settings_field(
			$name, $title, array($this, $field_callback),
			$page, $section, $callback_options
		);
		register_setting( $page, $name, array( $this, $validation ) );
    }

    /**
     * Render a settings textarea
     */
    public function field_textarea( $params ) {
        $name = $params['name'];
        $value = get_option( $name );
        $settings = array( 'textarea_name' => $name );

        wp_editor( $value, $name, $settings );
        if ( isset( $params['help'] ) && $params['help'] ) {
			echo '<br /><span class="description">' . $params['help'] . '</span>';
		}
    }

	/**
	* Render a info box
	*/
	public function field_info( $params ) {
		$description = $params['description'];
		echo '<div class="">' . $description . '</div>';
	}

	/**
    * Render a setings radio
    */
	public function field_radio( $params ) {
		$name = $params['name'];
		$title = $params['title'];
		$default = get_option( $name, null );
		if ( null == $default)
			$default = $params['default'];
		$values = $params['values'];
		echo '<div class="wpdp_radio">';
		foreach ($values as $key => $value) {
			echo '<input type="radio" name="' . $name . '" value="' . $key . '" '
				. ( ($default == $key) ? 'checked' : '' ) . '> ' . $value . '<br />';
		}
		echo '</div>';
		if ( isset( $params['help'] ) && $params['help'] ) {
	  		echo '<br /><span class="description">' . $params['help'] . '</span>';
	  	}
    }

	/**
    * Render a setings select
    */
    public function field_select( $params ) {
		$name = $params['name'];
		$title = $params['title'];
		$default = get_option( $name, null );
		if ( null == $default)
			$default = $params['default'];
		$values = $params['values'];
		echo '<select name="' . $name . '" id="' . $name . '" type="select" >';
		foreach ($values as $key => $value) {
			echo '<option value="' . $key .'" ' . ( ($default == $key) ? 'selected' : '' ) . '>' . $value . '</option>';
		}
		echo '</select>';
		if ( isset( $params['help'] ) && $params['help'] ) {
	  		echo '<br /><span class="description">' . $params['help'] . '</span>';
	  	}
    }

	/**
    * Render a setings multi select
    */
    public function field_multi_select( $params ) {
		$name = $params['name'];
		$title = $params['title'];
		$default = get_option( $name, array() );
		if ( null == $default)
			$default = $params['default'];
		if ( !is_array($default) ) {
			$default = array();
		}
		$values = $params['values'];
		echo '<select name="' . $name . '[]" id="' . $name . '" type="select" class="chosen_select" multiple>';
		foreach ($values as $key => $value) {
			echo '<option value="' . $key .'" ' . ( (in_array( $key, $default) ) ? 'selected' : '' ) . '>' . $value . '</option>';
		}
		echo '</select>';
		if ( isset( $params['help'] ) && $params['help'] ) {
	  		echo '<br /><span class="description">' . $params['help'] . '</span>';
	  	}
    }

    /**
    * Render a setings checkbox
    */
    public function field_checkbox( $params ) {
		$name = $params['name'];
		$title = $params['title'];
		$default = $params['default'] ? '1' : '0';

		echo '<input name="' . $name . '" id="' . $name . '" type="checkbox" value="1" class="" '
            . checked( 1, get_option( $name ), false )
            . ' /> ' . __( $title, 'dropwp_chatfree' );
		if ( isset( $params['help'] ) && $params['help'] ) {
	  		echo '<br /><span class="description">' . $params['help'] . '</span>';
	  	}
    }

	/**
    * Render a setings text input
    */
    public function field_simpletextarea( $params ) {
		$value = get_option( $params['name'] );
		echo '<textarea name="' . $params['name'] . '" rows="10">' . $value . '</textarea>';
		if ( isset( $params['help'] ) && $params['help'] ) {
			echo '<br /><span class="description">' . $params['help'] . '</span>';
		}
    }

    /**
    * Render a setings text input
    */
    public function field_text( $params ) {
		$value = get_option( $params['name'] );
		echo '<input type="text" name="' . $params['name'] . '" value="' . $value . '"/>';
		if ( isset( $params['help'] ) && $params['help'] ) {
			echo '<br /><span class="description">' . $params['help'] . '</span>';
		}
    }

    /**
    * Render a setings hidden input
    */
    public function field_hidden( $params ) {
        $value = get_option( $params['name'] );
		if ( is_array($value) ) {
			$value = json_encode( $value );
		}
        echo '<input type="hidden" name="' . $params['name'] . '" value=\'' . $value . '\'/>';
    }

    /**
     * Sanitize input values
     */
	function options_validate( $input ) {
		if ( is_array($input) ) {
			return $input;
		}

		return sanitize_text_field( $input );
	}

    /**
     * Validate pass
     */
	function pass_all_validate( $input ) {
		return $input ;
	}

}
